@@ -43,7 +43,7 @@ gettext.textdomain( 'backintime' )
 
 class Config( configfile.ConfigFileWithProfiles ):
     APP_NAME = 'Back In Time'
-    VERSION = '1.0.34'
+    VERSION = '1.0.36'
     COPYRIGHT = 'Copyright (c) 2008-2013 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze'
     CONFIG_VERSION = 5
 
@@ -95,7 +95,7 @@ class Config( configfile.ConfigFileWithProfiles ):
 
     MIN_FREE_SPACE_UNITS = { DISK_UNIT_MB : 'Mb', DISK_UNIT_GB : 'Gb' }
 
-    DEFAULT_EXCLUDE = [ '.gvfs', '.cache*', '[Cc]ache*', '.thumbnails*', '[Tt]rash*', '*.backup*', '*~', os.path.expanduser( '~/Ubuntu One' ), '.dropbox*', '/proc/*', '/sys/*', '/dev/*', '/run/*' ]
+    DEFAULT_EXCLUDE = [ '.gvfs', '.cache*', '[Cc]ache*', '.thumbnails*', '[Tt]rash*', '*.backup*', '*~', '.dropbox*', '/proc/*', '/sys/*', '/dev/*', '/run/*' ]
     
     exp = _(' EXPERIMENTAL!')
     SNAPSHOT_MODES = {
@@ -289,7 +289,7 @@ class Config( configfile.ConfigFileWithProfiles ):
             
                 if len( path ) >= len( snapshots_path2 ):
                     if path[ : len( snapshots_path2 ) ] == snapshots_path2:
-                        self.notify_error( _('Profile: "%s"') %  self.get_current_profile(), + '\n' + _('You can\'t include a backup sub-folder !') )
+                        self.notify_error( _('Profile: "%s"') %  self.get_current_profile() + '\n' + _('You can\'t include a backup sub-folder !') )
                         return False
 
             checked_profiles.append( ( profile_id, profile_name ) )
