@@ -106,8 +106,8 @@ class EncFS_mount(mount.MountControl):
         
     def pre_mount_check(self, first_run = False):
         """check what ever conditions must be given for the mount"""
+        self.check_fuse()
         if first_run:
-            self.check_fuse()
             self.check_version()
         return True
         
@@ -169,7 +169,8 @@ class EncFS_mount(mount.MountControl):
             try:
                 fuse_grp_members = grp.getgrnam('fuse')[3]
             except KeyError:
-                fuse_grp_members = []
+                #group fuse doesn't exist. So most likely it isn't used by this distribution
+                return
             if not user in fuse_grp_members:
                 raise mount.MountException( _('%(user)s is not member of group \'fuse\'.\n Run \'sudo adduser %(user)s fuse\'. To apply changes logout and login again.\nLook at \'man backintime\' for further instructions.') % {'user': user})
         
